const path = require('path');
const webpack = require('webpack');
const CopyWebpackPlugin = require('copy-webpack-plugin');
const HtmlWebpackPlugin = require('html-webpack-plugin');


const config = {
    context: path.resolve(__dirname, 'demo-src'),
    entry: {
        app: './demo.jsx',
        vendor: [
            'react',
            'react-dom',
            'react-router'
        ]
    },
    output: {
        path: path.resolve(__dirname, 'demo-dist'),
        publicPath: '/demo-dist/',
        filename: '[name].js?v=[hash:8]'
    },
    module: {
        rules: [
            {
                test: /\.js[x]?$/,
                include: [
                    path.resolve(__dirname, 'src'),
                    path.resolve(__dirname, 'demo-src')
                ],
                exclude: /node_modules/,
                loader: 'babel-loader'
            },
            {
                test: /\.css$/,
                include: [
                    path.resolve(__dirname, 'src'),
                    path.resolve(__dirname, 'demo-src'),
                ],
                loader: 'style-loader!css-loader'
            },
            {
                test: /\.(png|jpe?g|gif)(\?\S*)?$/,
                loader: 'url-loader',
                query: {
                    limit: 10000,  // 10k
                    name: 'images/[name].[ext]?v=[hash:8]'
                }
            },
            {
                test: /\.(eot|ttf|woff|woff2)(\?\S*)?$/,
                loader: 'file-loader',
                query: {
                    name: 'fonts/[name].[ext]?v=[hash:8]'
                }
            },
            {
                test: /\.svg$/,
                loader: 'file-loader',
                query: {
                    name: 'svgs/[name].[ext]?v=[hash:8]'
                }
            }
        ]
    },
    plugins: [
        new webpack.optimize.CommonsChunkPlugin({
            name: ['common', 'vendor'], // Specify the common bundle's name.
            minChunks: 2
        }),
        new HtmlWebpackPlugin({
            template: './demo.html',
            filename: 'demo.html',
            inject: false,
            // hash: false,
            // minify: {
            //     removeComments: true,
            //     collapseWhitespace: true
            //     // more options:
            //     // https://github.com/kangax/html-minifier#options-quick-reference
            // }
        }),
        new webpack.LoaderOptionsPlugin({
            minimize: true,
        }),
        new CopyWebpackPlugin([
            { from: './css/', to: 'css' }
            // { from: './font/', to: 'font' }
        ])
    ],
    devtool: '#cheap-eval-source-map'
};

if (process.env.NODE_ENV === 'production') {
    config.devtool = '#source-map';
    config.plugins = config.plugins.concat([
        new webpack.DefinePlugin({
            'process.env.NODE_ENV': '"production"'
        }),
        new webpack.optimize.UglifyJsPlugin({
            sourceMap: true,
            compress: {
                warnings: false,
                drop_console: true
            }
        })
    ]);
}


module.exports = config;
